@@ -110,6 +110,8 @@ class BaseTask(Persistent, Location):
     report_target = FieldProperty(ISchedulerTask['report_target'])
     report_mailer = FieldProperty(ISchedulerTask['report_mailer'])
     report_errors_only = FieldProperty(ISchedulerTask['report_errors_only'])
+    send_empty_reports = FieldProperty(ISchedulerTask['send_empty_reports'])
+    keep_empty_reports = FieldProperty(ISchedulerTask['keep_empty_reports'])
     _history_length = FieldProperty(ISchedulerTask['history_length'])
 
     def __init__(self):
@@ -258,8 +260,11 @@ class BaseTask(Persistent, Location):
                             hooks.setSite(site)
                             notify(BeforeJobRunEvent(task))
                             task.run(report)
+                            if report.getvalue():
+                                status = 'OK'
+                            else:
+                                status = 'Empty'
                             report.write('\n\nTask duration: ' + getDuration(start) + '\n')
-                            status = 'OK'
                         except:
                             status = 'Error'
                             task._logException(report, "An error occured during execution of task %s" % task.title)
@@ -292,6 +297,8 @@ class BaseTask(Persistent, Location):
 
     def storeReport(self, report, status):
         """Store execution report in task's history and send it by mail"""
+        if (status == 'Empty') and not self.keep_empty_reports:
+            return
         item = TaskHistoryItem()
         item.date = tztime(datetime.utcnow())
         item.status = status
@@ -306,7 +313,10 @@ class BaseTask(Persistent, Location):
             locate(item, self.history)
 
     def sendReport(self, report, status):
-        if self.report_target and ((status != 'OK') or (not self.report_errors_only)):
+        if self.report_target and \
+           ((status in ('Error', 'Warning')) or
+            ((status == 'Empty') and self.send_empty_reports) or
+            ((status == 'OK') and not self.report_errors_only)):
             mailer = queryUtility(IMailDelivery, self.report_mailer)
             if mailer is not None:
                 if status == 'Error':
@@ -334,7 +344,7 @@ class CronTaskScheduler(object):
 
     def getTrigger(self, task):
         if not self.marker_interface.providedBy(task):
-            raise Exception(_("Task is not configured for cron-style schduling !"))
+            raise Exception(_("Task is not configured for cron-style scheduling !"))
         info = self.schema(task)
         return CronTrigger(year=info.year or u'*',
                            month=info.month or u'*',
